==> va416xx-0.1.0.crate: va416xx-0.1.0/src/trng/sample_cnt1.rs <==
#[doc = "Register `SAMPLE_CNT1` reader"]
pub struct R(crate::R<SAMPLE_CNT1_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SAMPLE_CNT1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SAMPLE_CNT1_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SAMPLE_CNT1_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SAMPLE_CNT1` writer"]
pub struct W(crate::W<SAMPLE_CNT1_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SAMPLE_CNT1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SAMPLE_CNT1_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SAMPLE_CNT1_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SAMPLE_CNTR1` reader - Sets the number of clk cycles between two consecutive ring oscillator samples"]
pub struct SAMPLE_CNTR1_R(crate::FieldReader<u32, u32>);
impl SAMPLE_CNTR1_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        SAMPLE_CNTR1_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SAMPLE_CNTR1_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SAMPLE_CNTR1` writer - Sets the number of clk cycles between two consecutive ring oscillator samples"]
pub struct SAMPLE_CNTR1_W<'a> {
    w: &'a mut W,
}
impl<'a> SAMPLE_CNTR1_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | (value as u32 & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Sets the number of clk cycles between two consecutive ring oscillator samples"]
    #[inline(always)]
    pub fn sample_cntr1(&self) -> SAMPLE_CNTR1_R {
        SAMPLE_CNTR1_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - Sets the number of clk cycles between two consecutive ring oscillator samples"]
    #[inline(always)]
    pub fn sample_cntr1(&mut self) -> SAMPLE_CNTR1_W {
        SAMPLE_CNTR1_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Section TBD\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [sample_cnt1](index.html) module"]
pub struct SAMPLE_CNT1_SPEC;
impl crate::RegisterSpec for SAMPLE_CNT1_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [sample_cnt1::R](R) reader structure"]
impl crate::Readable for SAMPLE_CNT1_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [sample_cnt1::W](W) writer structure"]
impl crate::Writable for SAMPLE_CNT1_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SAMPLE_CNT1 to value 0xffff"]
impl crate::Resettable for SAMPLE_CNT1_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0xffff
    }
}

==> va416xx-0.1.1.crate: va416xx-0.1.1/src/trng/sample_cnt1.rs <==
#[doc = "Register `SAMPLE_CNT1` reader"]
pub struct R(crate::R<SAMPLE_CNT1_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SAMPLE_CNT1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SAMPLE_CNT1_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SAMPLE_CNT1_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SAMPLE_CNT1` writer"]
pub struct W(crate::W<SAMPLE_CNT1_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SAMPLE_CNT1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SAMPLE_CNT1_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SAMPLE_CNT1_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `SAMPLE_CNTR1` reader - Sets the number of clk cycles between two consecutive ring oscillator samples"]
pub struct SAMPLE_CNTR1_R(crate::FieldReader<u32, u32>);
impl SAMPLE_CNTR1_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        SAMPLE_CNTR1_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SAMPLE_CNTR1_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `SAMPLE_CNTR1` writer - Sets the number of clk cycles between two consecutive ring oscillator samples"]
pub struct SAMPLE_CNTR1_W<'a> {
    w: &'a mut W,
}
impl<'a> SAMPLE_CNTR1_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = value as u32;
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Sets the number of clk cycles between two consecutive ring oscillator samples"]
    #[inline(always)]
    pub fn sample_cntr1(&self) -> SAMPLE_CNTR1_R {
        SAMPLE_CNTR1_R::new(self.bits as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - Sets the number of clk cycles between two consecutive ring oscillator samples"]
    #[inline(always)]
    pub fn sample_cntr1(&mut self) -> SAMPLE_CNTR1_W {
        SAMPLE_CNTR1_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Section TBD\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [sample_cnt1](index.html) module"]
pub struct SAMPLE_CNT1_SPEC;
impl crate::RegisterSpec for SAMPLE_CNT1_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [sample_cnt1::R](R) reader structure"]
impl crate::Readable for SAMPLE_CNT1_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [sample_cnt1::W](W) writer structure"]
impl crate::Writable for SAMPLE_CNT1_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SAMPLE_CNT1 to value 0xffff"]
impl crate::Resettable for SAMPLE_CNT1_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0xffff
    }
}
